Description Usage Arguments Value Examples
histNA_byVar check the distribution of NAs of certain variable is affected by another variable
1 | histNA_byVar(dat, NAvar, byvar, bin = 30)
|
dat |
data frame |
NAvar |
variable with NAs |
byvar |
influencing variable |
bin |
number of bins (default is 30) |
two histogram of influencing variable which separated by the presence of NAs in the NAvar
1 2 3 4 | dat <- iris
dat[dat$Species == "setosa", "Sepal.Length"] <- NA
#indicate right-tailed missingness
histNA_byVar(dat, Sepal.Length, Sepal.Width)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.